# graph - Module Enrichment

**File:** `./src/autodoc/graph.py`
**Last Updated:** 2025-06-27T16:13:59.052029
**Total Entities:** 32
**Functions:** 1
**Classes:** 4

## Module Entities

*No enrichments available yet. Run `autodoc enrich` to add detailed descriptions.*

### Functions

#### `main` (line 703)
> Example usage of the graph functionality

### Classes

#### `CodeGraphBuilder` (line 43)
> Builds a graph representation of code in Neo4j

#### `CodeGraphQuery` (line 325)
> Query and analyze the code graph

#### `CodeGraphVisualizer` (line 483)
> Visualize the code graph

#### `GraphConfig` (line 24)
> Configuration for graph database connection
